@@ -127,6 +127,7 @@ extern Flag flag_initial_tab;
 extern Flag flag_line_number;
 extern Flag flag_smart_case;
 extern Flag flag_text;
+extern Flag flag_tree;
 extern Flag flag_ungroup;
 extern Sort flag_sort_key;
 extern Action flag_devices_action;
@@ -151,6 +152,7 @@ extern size_t flag_min_steal;
 extern size_t flag_not_magic;
 extern size_t flag_query;
 extern size_t flag_tabs;
+extern size_t flag_width;
 extern size_t flag_zmax;
 extern const char *flag_apply_color;
 extern const char *flag_binary_files;
